
*dataset used: DEMO BPX BMX BPQ ALQ SMQ PAQ DIQ MCQ DPQ SLQ PAQ  RHQ FASTQX HIQ HUQ
*recode of sociodemographic variable was omitted for simplicity 

/*
*metabolic syndrome
https://www.cdc.gov/pcd/issues/2017/16_0287.htm
*/


*met1: central obesity
recode bmxwaist (min/101.9=0) (102/max=1),gen(idfcobs)
replace idfcobs=1 if bmxwaist>=88 & sex==2


*met2: glucose
recode diq070 (1=1) (2=0) (7 9=.),gen(med_diab)
lab var med_diab "Diabetes medication"

recode lbxglu (min/99.9=0) (100/max=1),gen(idfglu)
replace idfglu=1 if med_diab==1 & idfglu<.

*met3: TG
recode lbxtr (min/149.9=0) (150/max=1),gen(idftg)
recode bpq090d (1=1) (2=0) (7 9=.),gen(med_tg)
replace idftg=1 if med_tg==1 & idftg<.

*met4: HDL
recode lbdhdd (min/39.9=1) (40/max=0),gen(idfhdl)
replace idfhdl=1 if lbdhdd<49.9 & sex==2
replace idfhdl=1 if med_tg==1 & idfhdl<.   //medication is the same as TG based on the literature

replace idfhdl=med_tg if wave==2 | wave==3  //wave 2 and 3 did not have information on HDL

*met5: hbp
recode bpxsy1 (min/129=0) (130/max=1),gen(idfhbp)
replace idfhbp=1 if bpxdi1>=85 & bpxdi1<.

recode bpq050a (1=1) (2=0) (7 9=.),gen(med_bp)   //current take hbp medication
replace med_bp=1 if bpq040a==1  //ever take hbp medication

replace idfhbp=1 if med_bp==1 & idfhbp<.

egen idf_miss=rowmiss(idfcobs idfglu idftg idfhdl idfhbp)
egen nmets=rowtotal(idfcobs idfglu idftg idfhdl idfhbp) if idf_miss==0
recode nmets (min/2=0) (3/5=1),gen(idfmets)
 

**# CircS definition

clonevar sleep=sld010h
replace sleep=sld012 if wave==9  //this is for 2015-16 survey, sleep duration has a different variable name
replace sleep=. if sleep==77 | sleep==99

recode sleep (min/6=2 "<=6") (6.1/8.9=1 "7-8") (9/max=3 ">=9"),gen(sleep3c)
lab var sleep3c "Sleep duration (hours)"


gen ssleep = sleep3c==2 if sleep3c<.
recode sleep3c (1=0 "Normal") (2 3=1 "Abnormal"),gen(dsleep)

mvdecode dpq010-dpq090,mv(7 9) 
egen phq_miss=rowmiss(dpq010-dpq090)
egen phq=rowtotal(dpq010-dpq090) if phq_miss==0
recode phq (min/4=0 No) (5/max=1 Yes),gen(phq9)
lab var phq9 "Clinically relevant depression"


*because the prevalence of depression is much lower than CHARLS, we used PHQ >=5 as cut off, to define depression

*CircS
gen ncs=nmets+ssleep+phq9


/*
mcq160b         byte    %10.0g                Ever told had congestive heart failure
mcq160c         byte    %10.0g                Ever told you had coronary heart disease
mcq160d         byte    %10.0g                Ever told you had angina/angina pectoris
mcq160e         byte    %10.0g                Ever told you had heart attack
mcq160f         byte    %10.0g                Ever told you had a stroke
*/

egen cvd = anymatch(mcq160b mcq160c mcq160d mcq160e mcq160f*), v(1) //	CVD
lab var cvd "CVD"

**# sample selection

**# sample selection, sample flow chart
cap drop smp*
local cond1 "ncs !=. & nmets <."
local cond2 "cvd<."
local cond3 "rhd143 !=1"

gen smp1 = 1 if age>=20 & age<.

forvalues i=1/3 {
	local j=`i'+1
	gen smp`j'=1 if smp`i'==1 & `cond`i''
}

su smp*

gen eli=smp4


clonevar mets=idfmets
recode ncs (min/3=0) (4/max=1),gen(cs)

gen wtmec12yr=1/6*wtsaf2yr   //fasting sample weight

svyset [w=wtmec12yr], psu(sdmvpsu) strata (sdmvstra)

egen metcs=group(mets cs)
lab define metcs 1 "Normal" 2 "CircS alone" 3 "MetS alone" 4 "Mets and CircS"
lab val metcs metcs

**# mortality data
merge 1:1 seqn using DEATH2019_D,gen(_mergecc)
merge 1:1 seqn using DEATH2019_E,update gen(_merge4)
merge 1:1 seqn using DEATH2019_F,update gen(_merge5)
merge 1:1 seqn using DEATH2019_G,update gen(_merge6)
merge 1:1 seqn using DEATH2019_H,update gen(_merge7)
merge 1:1 seqn using DEATH2019_I,update gen(_merge8)

************************
*survival setup
cap drop fyear
gen fyear=permth_int/12     //interview 
stset fyear [pweight=wtmec12yr] ///
if (wtmec12yr!=0) /*excludes those not examined in MEC*/, id(seqn) ///
failure(morts==1) 

*cancer death
stset fyear [pweight=wtmec12yr] ///
if (wtmec12yr!=0) /*excludes those not examined in MEC*/, id(seqn) ///
failure(ucod_leading==2) 

*CVD death
stset fyear [pweight=wtmec12yr] ///
if (wtmec12yr!=0) /*excludes those not examined in MEC*/, id(seqn) ///
failure(ucod_leading==1 5) 

*other death
stset fyear [pweight=wtmec10yr] ///
if (wtmec10yr!=0) /*excludes those not examined in MEC*/, id(seqn) ///
failure(ucod_leading==10) 

**# Table 2


global model1 "i.age"
global model2 "i.age i.sex i.race  i.lpa3c i.edu4c i.income3c i.smk i.drink"

foreach xvar in cvd   {
svy, subpop (if eli==1 & sex==1 ):logistic `xvar' nmets $model1 
svy, subpop (if eli==1 & sex==1 ):logistic `xvar' nmets $model2 

svy, subpop (if eli==1 & sex==2 ):logistic `xvar' nmets $model1 
svy, subpop (if eli==1 & sex==2 ):logistic `xvar' nmets $model2 


*MetS
svy, subpop (if eli==1 & sex==1 ):logistic `xvar' mets $model1 
svy, subpop (if eli==1 & sex==1 ):logistic `xvar' mets $model2 

svy, subpop (if eli==1 & sex==2 ):logistic `xvar' mets $model1 
svy, subpop (if eli==1 & sex==2 ):logistic `xvar' mets $model2 


*CS

svy, subpop (if eli==1 & sex==1 ):logistic `xvar' ncs $model1 
svy, subpop (if eli==1 & sex==1 ):logistic `xvar' ncs $model2 

svy, subpop (if eli==1 & sex==2 ):logistic `xvar' ncs $model1 
svy, subpop (if eli==1 & sex==2 ):logistic `xvar' ncs $model2 


svy, subpop (if eli==1 & sex==1 ):logistic `xvar' cs $model1 
svy, subpop (if eli==1 & sex==1 ):logistic `xvar' cs $model2 

svy, subpop (if eli==1 & sex==2 ):logistic `xvar' cs $model1 
svy, subpop (if eli==1 & sex==2 ):logistic `xvar' cs $model2 

}

**# Bookmark #5


global model1 "age "
global model2 "age i.sex i.race  i.lpa3c i.edu4c  i.smk i.drink"
**# MetS

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd nmets $model1 
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd nmets $model2 

collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd nmets $model1 
collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd nmets $model2 

myreg2 nmets,dp(2) ci(-)  
//myreg2 is a program to export results to word document. It was developed by Zumin Shi, available upon request through email: zumin.shi@gmail.com, or through website: https://github.com/zuminshi/Stata-code
putdocx save mytable2.docx,replace


collect clear
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd mets $model1 
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd mets $model2 

collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd mets $model1 
collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd mets $model2 

myreg2 mets,dp(2) ci(-)
putdocx save mytable2.docx,append

**# CS

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd ncs $model1 
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd ncs $model2 

collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd ncs $model1 
collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd ncs $model2 

myreg2 ncs,dp(2) ci(-)
putdocx save mytable2.docx,append

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd cs $model1 
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd cs $model2 

collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd cs $model1 
collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd cs $model2 

myreg2 cs,dp(2) ci(-)
putdocx save mytable2.docx,append
**# Bookmark #6


global model1 "age "
global model2 "age i.sex i.race  i.lpa3c i.edu4c  i.smk i.drink"


**# MetS

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): stcox nmets $model1 
collect:svy, subpop (if eli==1 & sex==1 ): stcox nmets $model2 

collect:svy, subpop (if eli==1 & sex==2 ): stcox nmets $model1 
collect:svy, subpop (if eli==1 & sex==2 ): stcox nmets $model2 

myreg2 nmets,dp(2) ci(-)
putdocx save mytable2.docx,replace


collect clear
collect:svy, subpop (if eli==1 & sex==1 ): stcox mets $model1 
collect:svy, subpop (if eli==1 & sex==1 ): stcox mets $model2 

collect:svy, subpop (if eli==1 & sex==2 ): stcox mets $model1 
collect:svy, subpop (if eli==1 & sex==2 ): stcox mets $model2 

myreg2 mets,dp(2) ci(-)
putdocx save mytable2.docx,append

**# CS

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): stcox ncs $model1 
collect:svy, subpop (if eli==1 & sex==1 ): stcox ncs $model2 

collect:svy, subpop (if eli==1 & sex==2 ): stcox ncs $model1 
collect:svy, subpop (if eli==1 & sex==2 ): stcox ncs $model2 

myreg2 ncs,dp(2) ci(-)
putdocx save mytable2.docx,append

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): stcox cs $model1 
collect:svy, subpop (if eli==1 & sex==1 ): stcox cs $model2 

collect:svy, subpop (if eli==1 & sex==2 ): stcox cs $model1 
collect:svy, subpop (if eli==1 & sex==2 ): stcox cs $model2 

myreg2 cs,dp(2) ci(-)
putdocx save mytable2.docx,append

**# Bookmark #7


global model1 "age "
global model2 "age i.sex i.race  i.lpa3c i.edu4c  i.smk i.drink"


**# prevalent CVD and CVD death

collect clear
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd i.metcs $model1 
collect:svy, subpop (if eli==1 & sex==1 ): logistic cvd i.metcs $model2 

collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd i.metcs $model1 
collect:svy, subpop (if eli==1 & sex==2 ): logistic cvd i.metcs $model2 

myreg2 metcs,dp(2) ci(-)
putdocx save mytable2.docx,replace


collect clear
collect:svy, subpop (if eli==1 & sex==1 ): stcox i.metcs $model1 
collect:svy, subpop (if eli==1 & sex==1 ): stcox i.metcs $model2 

collect:svy, subpop (if eli==1 & sex==2 ): stcox i.metcs $model1 
collect:svy, subpop (if eli==1 & sex==2 ): stcox i.metcs $model2 

myreg2 metcs,dp(2) ci(-)
putdocx save mytable2.docx,append


**# PPV and NPV
* ssc command
diagt cvd mets if eli==1 & sex==1
diagt cvd cs if eli==1 & sex==1

diagt cvd mets if eli==1 & sex==2
diagt cvd cs if eli==1 & sex==2

diagt death_cvd mets if eli==1 & sex==1
diagt death_cvd cs if eli==1 & sex==1

diagt death_cvd mets if eli==1 & sex==2
diagt death_cvd cs if eli==1 & sex==2

